@@ -1,6 +1,16 @@
 from PyObjCTools.TestSupport import *
 from CFNetwork import *
 
+try:
+    long
+except NameError:
+    long = int
+
+try:
+    unicode
+except NameError:
+    unicode = str
+
 
 class TestCFNetwork (TestCase):
 
@@ -14,6 +24,8 @@ class TestCFNetwork (TestCase):
         self.assertIsInstance(kCFSOCKSNegotiationMethodKey, unicode)
         self.assertIsInstance(kCFDNSServiceFailureKey, unicode)
         self.assertIsInstance(kCFFTPStatusCodeKey, unicode)
+        self.assertIsInstance(kCFURLErrorFailingURLErrorKey, unicode)
+        self.assertIsInstance(kCFURLErrorFailingURLStringErrorKey, unicode)
 
     @min_os_level('10.6')
     def testConstants10_6(self):
@@ -66,8 +78,6 @@ class TestCFNetwork (TestCase):
         self.assertEqual(kCFURLErrorDownloadDecodingFailedToComplete, -3007)
         self.assertEqual(kCFHTTPCookieCannotParseCookieFile, -4000)
 
-        self.assertIsInstance(kCFURLErrorFailingURLErrorKey, unicode)
-        self.assertIsInstance(kCFURLErrorFailingURLStringErrorKey, unicode)
 
 
     def testConstants(self):
@@ -104,5 +114,9 @@ class TestCFNetwork (TestCase):
         self.assertEqual(kCFErrorHTTPBadProxyCredentials, 307)
         self.assertEqual(kCFErrorPACFileError, 308)
 
+    @min_os_level('10.8')
+    def testConstants10_8(self):
+        self.assertEqual(kCFStreamErrorHTTPSProxyFailureUnexpectedResponseToCONNECTMethod, 311)
+
 if __name__ == "__main__":
     main()
